from numpy import *
from pylab import *

from helmholtz_mfs import *

def norm2(x):
    return sqrt(sum(abs(x)**2))

def prob_0(n, rho):
    k = 8
    m = 240
    R = 1.5
    z_source = array([rho, 0])
    return prob_disc_source_dir(k, z_source, m, R, n)

if __name__ == "__main__":
    rhos = [ 3, 1.7, 1.1 ]
    nmaxs = [ 150, 150, 200 ]
    xb = unit_circle(2*nmaxs[-1])
    figure(3)
    clf()
    for i, (rho, nmax) in enumerate(zip(rhos, nmaxs)):
        ns = arange(1, nmax+1, 10)
        prob = prob_0(1, rho)
        subplot(1, 3, i+1)
        plot(ns, prob.R**(-ns), 'b-')
        plot(ns, rho**(-ns/2.0), 'g--')
        print rho, prob.R
        if rho < prob.R:
            plot(ns, (prob.R/rho)**(ns/2.0), 'r.')
        u = prob.sol(xb)
        normcs = []
        errs = []
        for n in ns:
            prob = prob_0(n, rho)
            c = linls(prob, prob.z)
            normcs.append(norm2(c))
            v = prob.sol_eval(prob.z, c, xb)
            errs.append(norm2(v - u))
        semilogy(ns, errs, 'b+')
        semilogy(ns, normcs, 'go')
        title(r"$\rho = %g$" % rho)
        xlabel("n")
        ylim(ymin=1e-16)
    show()
